<?php
namespace FiloBlu\Flow\Block\Adminhtml\Inboundflow\Edit\Tab;
class General extends \Magento\Backend\Block\Widget\Form\Generic implements \Magento\Backend\Block\Widget\Tab\TabInterface
{
    /**
     * @var \Magento\Store\Model\System\Store
     */
    protected $_systemStore;

    /**
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Data\FormFactory $formFactory
     * @param \Magento\Store\Model\System\Store $systemStore
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Magento\Store\Model\System\Store $systemStore,
        array $data = array()
    ) {
        $this->_systemStore = $systemStore;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
		/* @var $model \Magento\Cms\Model\Page */
        $model = $this->_coreRegistry->registry('flow_inboundflow');
		$isElementDisabled = false;
        /** @var \Magento\Framework\Data\Form $form */
        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('page_');

        $fieldset = $form->addFieldset('base_fieldset', array('legend' => __('General')));

        if ($model->getId()) {
            $fieldset->addField('id', 'hidden', array('name' => 'id'));
        }

		$fieldset->addField(
            'name',
            'text',
            array(
                'name' => 'name',
                'label' => __('name'),
                'title' => __('name'),
                /*'required' => true,*/
            )
        );
		$fieldset->addField(
            'priority',
            'select',
            array(
                'name' => 'priority',
                'label' => __('priority'),
                'title' => __('priority'),
                'options'   => array(
                    'low' => 'LOW',
                    'normal' => 'NORMAL',
                ),
                /*'required' => true,*/
            )
        );
        $fieldset->addField(
            'status',
            'select',
            array(
                'name' => 'status',
                'label' => __('status'),
                'title' => __('status'),
                'options'   => array(
                    '' => 'Nessuno Stato',
                    'found' => 'FOUND',
                    'receiving' => 'RECEIVING',
                    'received' => 'RECEIVED',
                    'parsing' => 'PARSING',
                    'parsed' => 'PARSED',
                    'processing' => 'PROCESSING',
                    'processed' => 'PROCESSED',
                    'error' => 'ERROR'
                ),
                'required' => true,
            )
        );
        $fieldset->addField(
            'log',
            'textarea',
            array(
                'name' => 'log',
                'label' => __('Log'),
                'title' => __('Log'),
                /*'required' => true,*/
            )
        );
        $fieldset->addField(
            'comment',
            'textarea',
            array(
                'name' => 'comment',
                'label' => __('comment'),
                'title' => __('comment'),
                /*'required' => true,*/
            )
        );
        
        if (!$model->getId()) {
            $model->setData('status', $isElementDisabled ? '2' : '1');
        }

        $form->setValues($model->getData());
        $this->setForm($form);

        return parent::_prepareForm();   
    }

    /**
     * Prepare label for tab
     *
     * @return string
     */
    public function getTabLabel()
    {
        return __('General');
    }

    /**
     * Prepare title for tab
     *
     * @return string
     */
    public function getTabTitle()
    {
        return __('General');
    }

    /**
     * {@inheritdoc}
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * {@inheritdoc}
     */
    public function isHidden()
    {
        return false;
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     * @return bool
     */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }
}
